@@ -106,5 +106,8 @@ register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBELO")
 register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBGP4PIR")
 register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBDMI")
 register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBDMI-R")
+register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBIN")
+register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBKP")
+register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBELPIR")
 register_command(COMMAND_CODE, ChannelNamePart1Message3, "VMB1BL")
 register_command(COMMAND_CODE, ChannelNamePart1Message3, "VMB2BL")
